<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Mode avion activé</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Mode avion désactivé</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Réglages du mode avion</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mode avion</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Mes périphériques</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Éteint</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Désactivez d&apos;abord le [Mode avion](#) si vous souhaitez vous connecter à un périphérique Bluetooth.</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Allumer</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Paramètres Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connecté</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Connexion...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Eteint</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Connecté à %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connecté</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Désactivé</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Réglages de l&apos;affichage</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Réglages de l&apos;affichage</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Luminosité</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Dim</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Lun</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Mer</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Jeu</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Ven</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Sam</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Ajouter une disposition de clavier</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Date et heure</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Affichage 12 heures</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Affichage 24 heures</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Réglages de l&apos;heure</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Ouvrir le calendrier</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Lundi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Mardi</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mercredi</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jeudi</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vendredi</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samedi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Dimanche</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>lundi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>mardi</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>mercredi</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>jeudi</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>vendredi</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>samedi</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>dimanche</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Autres périphériques</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode Ne pas déranger</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Réglages du mode Ne pas déranger</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Désactiver</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Activer</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Mode Ne pas déranger activé</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Mode Ne pas déranger désactivé</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Mode Ne pas déranger</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Confort pour les yeux</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Confort pour les yeux activé</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Confort pour les yeux activés</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Réglages de l&apos;affichage</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Confort pour les yeux</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Activé</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Désactivé</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sombre</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Désactivé le confort des yeux</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Activer le confort des yeux</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Réglages de l&apos;affichage</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Thème : Clair</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Thème : Sombre</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Thème : Automatique</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Effets visuels</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Sombre</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatique</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Aucun message</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Réglages des notifications</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notifications</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Désactiver le mode Ne Pas Déranger</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Activer le mode Ne Pas Déranger</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Notification</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Clavier virtuel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Haute performance</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Équilibré</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Économie d&apos;énergie</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Performance équilibrée</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Batterie</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capacité  %1, %2 minutes restantes</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capacité %1, %2 heures et %3 minutes restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>En charge %1, %2 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>En charge %1, %2 heures et %3 minutes avant la charge complète</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>En charge %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capacité %1</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capacité %1, complètement chargé</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Capacité %1, pas en charge</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Batterie</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>En charge, calcul de l&apos;estimation du temps de chargement</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Calcul du temps d&apos;utilisation restant</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>%1 minutes restantes</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>%1 h %2 restant</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Pas en charge</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Complètement chargé</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>En charge, %1 minutes avant charge complète</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>En charge, %1 h %2 avant la charge complète</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Capacité %1, %2 heures restantes</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>%1 heures restantes</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>En charge %1, %2 heures avant la charge complète</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>En charge, %1 heures avant charge complète</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Musique</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Eteindre</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Mettre en veille</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Mettre en veille prolongée</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Verrouiller</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Options d&apos;alimentation</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Mettre à jour puis éteindre</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Mettre à jour puis redémarrer</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Éteindre</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Changer d&apos;utilisateur</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Aujourd&apos;hui</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lunaire</translation>
    </message>
    <message>
        <source>y</source>
        <translation>a</translation>
    </message>
    <message>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <source>d</source>
        <translation>j</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Lundi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Mardi</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mercredi</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Jeudi</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vendredi</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samedi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Dimanche</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Jan</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Fév</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Mar</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Avr</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Juin</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Juil</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Août</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Sept</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Oct</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Nov</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Déc</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Ouvrir le calendrier</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>lundi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>mardi</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>mercredi</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>jeudi</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>vendredi</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>samedi</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>dimanche</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Réglages du son</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Réactiver le son</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Muet</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Réglages du son</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Aucun périphérique de sortie</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volume %1</translation>
    </message>
</context>
</TS>